@@ -102,10 +102,19 @@ ROLE_TEST_GAP=88
 
 ROLE_CM_NUM=83
 ROLE_RT_NUM=84
+ROLE_UNREAD = 82
 
 SETTINGS_ATT_NAMES=[
         "downpic",
-        "updatenum"
+        "updatenum",
+        "background",
+        "updateinterval",
+        "notify_led",
+        "notify_vibra",
+        "notify_sound",
+        "updateinterval2",
+        "down_orgpic",
+        "auto_conn"
         ]
         
 STATUS_ATT_COUNTS=[
@@ -113,6 +122,22 @@ STATUS_ATT_COUNTS=[
         "comments",
         "rt",
         ]
+        
+UNREAD_ATT_COUNTS=[
+        "comments",
+        "followers",
+        "dm",
+        "mentions",
+        ]
+        
+UNREAD_ATT_COUNTS_QQ=[
+        "home",
+        "create",
+        "fans",
+        "private",
+        "mentions",
+        ]
+
 
 STATUS_ATT_NAMES=[
         "status_id",
@@ -175,6 +200,7 @@ ACCOUNT_ATT_NAMES=[
         "nickname",
         "username",
         "password",
+        "auto_update",
         "last_update_time_friends",
         "last_update_time_mentions",
         "last_update_time_comments",
@@ -193,6 +219,8 @@ TIMELINE_TYPE_MENTIONS=3
 TIMELINE_TYPE_COMMENTS=4
 TIMELINE_TYPE_FAVOUR=5
 TIMELINE_TYPE_ST_COMMENTS=6
+TIMELINE_TYPE_UNREAD=7
+TIMELINE_TYPE_DEUNREAD=8
 
 NEW_A_STATUS=11
 
@@ -237,8 +265,16 @@ def build_settings_from_row(obj):
     result = {}
     
     if obj==None:
-        result["downpic"]="True"
+        result["downpic"]="False"
+        result["background"]="False"
         result["updatenum"]="10"
+        result["updateinterval"]="1"
+        result["updateinterval2"]="10"
+        result["notify_led"]="True"
+        result["notify_vibra"]="False"
+        result["notify_sound"]="True"
+        result["down_orgpic"]="True"
+        result["auto_conn"]="---None---"
         return result
         
     for att in SETTINGS_ATT_NAMES:
@@ -356,6 +392,31 @@ def build_a_count_from_obj(obj,accountId):
             result[att]=None
     return result        
 
+def build_a_unread_count_from_obj(obj):
+    result = {}
+    for att in UNREAD_ATT_COUNTS:
+        try:
+            result[att]=getattr(obj,att)
+            #print att, result[att]
+        except AttributeError:
+            result[att]=0
+            #print att, result[att]
+    return result     
+    
+def build_a_unread_count_from_obj_qq(obj):
+    result = {}
+    for att in UNREAD_ATT_COUNTS:
+        #print att
+        try:
+            result[att]=obj[att]
+            #print att, result[att]
+        except:
+            result[att]=0
+            #print att, result[att]
+    return result    
+
+
+
 def dump(obj):
     for attr in dir(obj):
         print "obj.%s = %s" % (attr, getattr(obj, attr))
@@ -609,6 +670,7 @@ CREATE TABLE [account]
 [nickname] VARCHAR,
 [username] VARCHAR,
 [password] VARCHAR,
+[auto_update] VARCHAR,
 [last_update_time_friends] DATETIME,
 [last_update_time_mentions] DATETIME,
 [last_update_time_comments] DATETIME,
@@ -681,6 +743,14 @@ SQL_CREATE_SETTINGS_TABLE="""
 CREATE TABLE IF NOT EXISTS [settings]
 (
 [downpic] VARCHAR,
-[updatenum] VARCHAR
+[updatenum] VARCHAR,
+[background] VARCHAR,
+[updateinterval] VARCHAR,
+[notify_led] VARCHAR,
+[notify_vibra] VARCHAR,
+[notify_sound] VARCHAR,
+[updateinterval2] VARCHAR,
+[down_orgpic] VARCHAR,
+[auto_conn] VARCHAR
 )
 """
