@@ -127,9 +127,9 @@ class MaoboApp(QApplication):
         self.currentAccount=None
 
         self.commentid_seed = 0
+        self.create_default_window()
         self.create_accounts_window()
         if len(self.accounts)==0:
-            self.create_default_window()
             self.defaultWin.show()
         else:
             self.accountsWin.show()
@@ -386,8 +386,13 @@ class MaoboApp(QApplication):
                     sender.start()    
         elif method == "top_application":
             print "top_application"
-            self.accountsWin.activateWindow()
-            self.accountsWin.show()
+            
+            if len(self.accounts)==0:
+                self.defaultWin.activateWindow()
+                self.defaultWin.show()
+            else:
+                self.accountsWin.activateWindow()
+                self.accountsWin.show()
         elif method == "open_mentions":
             #args[0] = account_idx, args[1] = optype
             print "open_mentions", args[0], args[1]
